@@ -80,7 +80,7 @@ image_read <- function(path, density = NULL, depth = NULL, strip = FALSE, define
     magick_image_readbin(path, density, depth, strip, defines)
   } else if(is.character(path) && all(nchar(path))){
     path <- vapply(path, replace_url, character(1))
-    magick_image_readpath(enc2native(path), density, depth, strip, defines)
+    magick_image_readpath(enc2utf8(path), density, depth, strip, defines)
   } else {
     stop("path must be URL, filename or raw vector")
   }
