@@ -48,6 +48,13 @@ Magick::ColorspaceType ColorSpace(const char * str){
   return (Magick::ColorspaceType) val;
 }
 
+Magick::InterlaceType Interlace(const char * str){
+  ssize_t val = MagickCore::ParseCommandOption( MagickCore::MagickInterlaceOptions, Magick::MagickFalse, str);
+  if(val < 0)
+    throw std::runtime_error(std::string("Invalid InterlaceType value: ") + str);
+  return (Magick::InterlaceType) val;
+}
+
 Magick::NoiseType Noise(const char * str){
   ssize_t val = MagickCore::ParseCommandOption(
     MagickCore::MagickNoiseOptions, Magick::MagickFalse, str);
@@ -121,6 +128,22 @@ Magick::StyleType FontStyle(const char * str){
   return (Magick::StyleType) val;
 }
 
+Magick::DecorationType FontDecoration(const char * str){
+  ssize_t val = MagickCore::ParseCommandOption(
+    MagickCore::MagickDecorateOptions, Magick::MagickFalse, str);
+  if(val < 0)
+    throw std::runtime_error(std::string("Invalid DecorationType value: ") + str);
+  return (Magick::DecorationType) val;
+}
+
+Magick::DistortMethod DistortionMethod(const char * str){
+  ssize_t val = MagickCore::ParseCommandOption(
+    MagickCore::MagickDistortOptions, Magick::MagickFalse, str);
+  if(val < 0)
+    throw std::runtime_error(std::string("Invalid DistortMethod value: ") + str);
+  return (Magick::DistortMethod) val;
+}
+
 #if MagickLibVersion >= 0x700
 Magick::Point Point(const char * str){
   Magick::Point point(str);
@@ -228,7 +251,7 @@ XPtrImage magick_image_implode( XPtrImage input, double factor){
 // [[Rcpp::export]]
 XPtrImage magick_image_format( XPtrImage input, Rcpp::CharacterVector format, Rcpp::CharacterVector type,
                                Rcpp::CharacterVector space, Rcpp::IntegerVector depth, Rcpp::LogicalVector antialias,
-                               Rcpp::LogicalVector matte){
+                               Rcpp::LogicalVector matte, Rcpp::CharacterVector interlace){
   XPtrImage output = copy(input);
   if(antialias.size()){
     for (Iter it = output->begin(); it != output->end(); ++it)
@@ -243,6 +266,8 @@ XPtrImage magick_image_format( XPtrImage input, Rcpp::CharacterVector format, Rc
     for_each ( output->begin(), output->end(), Magick::colorSpaceImage(ColorSpace(space.at(0))));
   if(depth.size())
     for_each ( output->begin(), output->end(), Magick::depthImage(depth.at(0)));
+  if(interlace.size())
+    for_each ( output->begin(), output->end(), Magick::interlaceTypeImage(Interlace(interlace.at(0))));
   if(format.size())
     for_each ( output->begin(), output->end(), Magick::magickImage(std::string(format.at(0))));
   return output;
@@ -305,7 +330,8 @@ XPtrImage magick_image_reducenoise( XPtrImage input, const size_t radius){
 // [[Rcpp::export]]
 XPtrImage magick_image_annotate( XPtrImage input, Rcpp::CharacterVector text, const char * gravity,
                                  const char * location, double rot, double size, const char * font,
-                                 const char * style, double weight, Rcpp::CharacterVector color,
+                                 const char * style, double weight, double kerning,
+                                 Rcpp::CharacterVector decoration, Rcpp::CharacterVector color,
                                  Rcpp::CharacterVector strokecolor, Rcpp::CharacterVector boxcolor){
   XPtrImage output = copy(input);
   typedef std::container<Magick::Drawable> drawlist;
@@ -321,6 +347,12 @@ XPtrImage magick_image_annotate( XPtrImage input, Rcpp::CharacterVector text, co
     draw.push_back(Magick::DrawableFillColor(Color(color[0])));
   if(boxcolor.size())
     draw.push_back(Magick::DrawableTextUnderColor(Color(boxcolor[0])));
+#if MagickLibVersion >= 0x689
+  if(kerning != 0)
+    draw.push_back(Magick::DrawableTextKerning(kerning));
+#endif
+  if(decoration.size())
+    draw.push_back(Magick::DrawableTextDecoration(FontDecoration(decoration[0])));
   draw.push_back(Magick::DrawablePointSize(size));
   draw.push_back(Magick::DrawableFont(normalize_font(font), FontStyle(style), weight, Magick::NormalStretch));
   if(rot){
@@ -365,3 +397,10 @@ XPtrImage magick_image_compare( XPtrImage input, XPtrImage reference_image, cons
 #endif
 }
 
+// [[Rcpp::export]]
+XPtrImage magick_image_distort(XPtrImage input, std::string method, Rcpp::NumericVector values, bool bestfit){
+  XPtrImage out = copy(input);;
+  for_each (out->begin(), out->end(),
+            Magick::distortImage(DistortionMethod(method.c_str()), values.size(), values.begin(), bestfit));
+  return out;
+}
